function h = fill_plot_simple(time,top,bottom,color)
% function h = fill_plot_simple(time, top, bottom, color)
%	
%	Inputs
%		time - row vector with time values same length as top and bottom
%		top - row vector with y-values for top of area
%		bottom - row vector with y-values for bottom of area
%		color - code for fill color
%
%	RST 2019-10

x = [time flip(time,2)];

y = [top flip(bottom,2)];
h = fill(x,y,color,'EdgeColor','none');


